thorn.django.signals — Thorn 1.3.0 documentation

# thorn.django.signals

- thorn.django.signals

## thorn.django.signals

Django signal dispatchers.

class `thorn.django.signals.` `dispatch_on_create`(fun, use_transitions=False, **kwargs)
  `setup_signals`()
  `should_dispatch`(instance, raw=False, created=False, **kwargs)

class `thorn.django.signals.` `dispatch_on_change`(fun, use_transitions=False, **kwargs)
  `on_pre_save`(instance, sender, raw=False, **kwargs)
  `setup_signals`()
  `should_dispatch`(instance, created=False, raw=False, **kwargs)

class `thorn.django.signals.` `dispatch_on_delete`(fun, use_transitions=False, **kwargs)
  `setup_signals`()

class `thorn.django.signals.` `dispatch_on_m2m_add`(fun, related_field, **kwargs)
  `setup_actions`()

class `thorn.django.signals.` `dispatch_on_m2m_remove`(fun, related_field, **kwargs)
  `setup_actions`()

class `thorn.django.signals.` `dispatch_on_m2m_clear`(fun, related_field, **kwargs)
  `setup_actions`()